@@ -8,9 +8,9 @@ use Log::ger;
 use Time::HiRes qw(time);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-08'; # DATE
+our $DATE = '2022-05-26'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(cek_bpom_products);
@@ -37,6 +37,12 @@ sub _encode {
     $str;
 }
 
+sub _strip_tags {
+    my $str = shift;
+    $str =~ s!</?[^>]+>!!g;
+    $str;
+}
+
 $SPEC{cek_bpom_products} = {
     v => 1.1,
     summary => 'Search BPOM products via https://cekbpom.pom.go.id/',
@@ -294,12 +300,63 @@ sub cek_bpom_products {
                 next;
             }
             my $ct = $res->content;
-            $ct =~ m!<td[^>]*>Diproduksi Oleh</td><td><a href="[^"]+sarana/[^"]+/id/([^"]+)"[^>]*>\s*([^<]+?)\s*</a> - ([^<]+?)\s*</td>! or do {
-                log_warn "Cannot get manufacturer detail for $row->{reg_id} ($row->{nama}), skipped";
+
+            ($ct =~ m!<td[^>]*>Diproduksi Oleh</td><td><a href="[^"]+sarana/[^"]+/id/([^"]+)"[^>]*>\s*([^<]+?)\s*</a> - ([^<]+?)\s*</td>! or
+             $ct =~ m!<td[^>]*>Diproduksi Oleh</td><td><a href="[^"]+sarana/[^"]+/id/([^"]+)"[^>]*>\s*([^<]+?)\s* - ([^<]+?)\s*</a></td>!) and do {
+                $row->{sarana_id} = $1;
+                $row->{sarana_nama} = $2;
+                $row->{sarana_negara} = $3;
+            } or do {
+                log_warn "Cannot get manufacturer detail ('Diproduksi Oleh') for $row->{reg_id} ($row->{nama})";
             };
-            $row->{sarana_id} = $1;
-            $row->{sarana_nama} = $2;
-            $row->{sarana_negara} = $3;
+
+            $ct =~ m!<td[^>]*>Produk</td><td>(.*?)</td>! and do {
+                $row->{product_category} = $1;
+            } or do {
+                log_warn "Cannot get product_category ('Produk') for $row->{reg_id} ($row->{nama})";
+                $row->{product_category} = ''; # to avoid undef warning
+            };
+
+            $ct =~ m!<td[^>]*>Masa Berlaku s/d</td><td>([0-9][0-9])-([0-9][0-9])-([0-9][0-9][0-9][0-9])! and do {
+                $row->{expiry_date} = "$3-$2-$1";
+            } or do {
+                # cosmetics usually have issue_date instead of expiry_date
+                # drugs usually have both
+                if ($row->{product_category} !~ /Kosmetika/) {
+                    log_warn "Cannot get expiry_date ('Masa Berlaku s/d') for $row->{reg_id} ($row->{nama})";
+                }
+            };
+
+            $ct =~ m!<td[^>]*>Tanggal Terbit</td><td>([0-9][0-9])-([0-9][0-9])-([0-9][0-9][0-9][0-9])! and do {
+                $row->{issue_date} = "$3-$2-$1";
+            } or do {
+                if ($row->{product_category} =~ /Kosmetika|Obat/) {
+                    log_warn "Cannot get issue_date ('Tanggal Terbit') for $row->{reg_id} ($row->{nama})";
+                }
+            };
+
+            $ct =~ m!<td[^>]*>Bentuk Sediaan</td><td>(.*?)</td>! and do {
+                $row->{dosage_form} = $1;
+            } or do {
+                if ($row->{product_category} =~ /Obat/) {
+                    log_warn "Cannot get dosage_form ('Bentuk Sediaan') for $row->{reg_id} ($row->{nama})";
+                }
+            };
+
+            $ct =~ m!<td[^>]*>Komposisi</td><td>(.*?)</td>! and do {
+                $row->{ingredients} = _strip_tags($1);
+            } or do {
+                if ($row->{product_category} =~ /Obat/) {
+                    log_warn "Cannot get ingredients ('Komposisi') for $row->{reg_id} ($row->{nama})";
+                }
+            };
+
+            $ct =~ m!<td[^>]*>Diterbitkan Oleh</td><td>(.*?)</td>! and do {
+                $row->{bpom_division} = $1;
+            } or do {
+                log_warn "Cannot get bpom_division ('Diterbitkan Oleh') for $row->{reg_id} ($row->{nama})";
+            };
+
             my $session_id = $1;
         }
     } # GET_PRODUCT_DETAIL
@@ -387,7 +444,7 @@ App::CekBpom - Check registered products & manufacturers (CLIs for cekbpom.pom.g
 
 =head1 VERSION
 
-This document describes version 0.021 of App::CekBpom (from Perl distribution App-CekBpom), released on 2022-05-08.
+This document describes version 0.022 of App::CekBpom (from Perl distribution App-CekBpom), released on 2022-05-26.
 
 =head1 DESCRIPTION
 
@@ -542,14 +599,13 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
-L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
-that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
